@@ -4,8 +4,8 @@ use strict;
 use Wx;
 use Wx::Html;
 
-our $VERSION = '0.71';
-our @ISA     = 'Wx::Html';
+our $VERSION = '0.72';
+our @ISA     = 'Wx::HtmlWindow';
 
 sub new {
 	shift->SUPER::new(@_);
