@@ -6,7 +6,7 @@ use Test::Builder;
 use Test::LongString;
 use Exporter ();
 
-our $VERSION = '0.71';
+our $VERSION = '0.72';
 our @ISA     = 'Exporter';
 our @EXPORT  = qw{ code compiles slurp };
 
@@ -24,7 +24,8 @@ sub code {
 }
 
 sub compiles {
-	my $code = shift;
+	my $code    = shift;
+	my $package = shift;
 	if ( ref $code ) {
 		$code = join '', map { "$_\n" } @$code;
 	}
@@ -32,12 +33,33 @@ sub compiles {
 		local $Test::Builder::Level = $Test::Builder::Level + 1;
 		my $Test = Test::Builder->new;
 		if ( $ENV{ADAMK_RELEASE} ) {
-			$Test->ok( 1, "Skipped $_[0]" );
+			foreach ( 1 .. 4 ) {
+				$Test->ok( 1, "Skipped $_[0]" );
+			}
 		} else {
+			# Compile the dialog
 			local $@;
-			my $rv = do { eval "return 1;\n$code"; };
+			unless ( $package ) {
+				$code = "return 1; $code";
+			}
+			my $rv = do { eval $code };
 			$Test->diag( $@ ) if $@;
 			$Test->ok( $rv, $_[0] );
+
+			# Try to create the object
+			if ( $package ) {
+				Test::More::use_ok('Wx');
+				my $app = Wx::SimpleApp->new;
+				Test::More::isa_ok( $app, 'Wx::App' );
+
+				# Create the Form
+				my $form = $package->new;
+				Test::More::isa_ok( $form, 'Wx::Object' );
+			} else {
+				foreach ( 1 .. 3 ) {
+					$Test->ok( 1, "Skipped $_[0]" );
+				}
+			}
 		}
 	}
 }
